/**
 *  Case Study: "From Hello World to MVC"
 *  Authors: Maria Litvin and Gary Litvin
 *  February 2002
 *
 *  Project 5: The model (Sphere), view (TextView), and controller (SphereWindow)
 *             are in separate classes.
 *             When the model changes the view is notified and updated automatically.
 *
 *  The Sphere class is derived from Observable and inherits its methods  
 *    setChanged() and notifyObservers().
 */

import java.util.Observable;

class Sphere extends Observable
{
  private double myRadius;
  private double myCenterX;
  private double myCenterY;

  // Constructors:

  Sphere (double x, double y, double r)
  {
    myCenterX = x;
    myCenterY = y;
    myRadius = r;
  }

  // etc.

  // Accessors and modifiers:

  public double getRadius()
  {
    return myRadius;
  }

  public double getX()
  {
    return myCenterX;
  }

  public double getY()
  {
    return myCenterY;
  }

  public void setRadius(double r)
  {
    myRadius = r;
    setChanged();         // Indicates that the model has changed
    notifyObservers();
  }

  // Other public methods:

  public void move(double x, double y)
  {
    myCenterX = x;
    myCenterY = y;
  }

  public double volume()
  {
    return 4.0 / 3.0 * Math.PI * myRadius * myRadius * myRadius;
  }


  public double surfaceArea()
  {
    return 4.0 * Math.PI * myRadius * myRadius;
  }

  public String toString()
  {
    return "Sphere [Center = (" + myCenterX + ", " + myCenterY + ") Radius = " + myRadius
           + "]"; 
  }
}
