/**
 *  Case Study: "From Hello World to MVC"
 *  Authors: Maria Litvin and Gary Litvin
 *  February 2002
 *
 *  Project 5: The model (Sphere), view (TextView), and controller (SphereWindow)
 *             are in separate classes.
 *             When the model changes the view is notified and updated automatically.
 *
 *  This TextView class is a view for the model.
 *  It implements the Observer interface and supplies the update method.
 *  update is called automatically when the model changes.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.text.DecimalFormat;
import java.util.Observer;
import java.util.Observable;

public class TextView extends JPanel
    implements Observer
{
  private JTextField radiusIn, volumeOut, surfAreaOut;
  private DecimalFormat f3 = new DecimalFormat("0.000");

  public TextView()
  {
    setLayout(new GridLayout(6, 2, 10, 10));
    setBorder(new EmptyBorder(10, 10, 10, 10));

    add(new JLabel("Radius = ", SwingConstants.RIGHT));

    radiusIn = new JTextField(8);
    radiusIn.setBackground(Color.yellow);
    add(radiusIn);

    add(new JLabel("Volume = ", SwingConstants.RIGHT));

    volumeOut = new JTextField(8);
    volumeOut.setEditable(false);
    volumeOut.setBackground(Color.white);
    add(volumeOut);

    add(new JLabel("Surface area = ", SwingConstants.RIGHT));

    surfAreaOut = new JTextField(8);
    surfAreaOut.setEditable(false);
    surfAreaOut.setBackground(Color.white);
    add(surfAreaOut);

    add (new JPanel());   // filler
  }

  public void addActionListener(ActionListener listener)
  {
    radiusIn.addActionListener(listener);
  }

  // This method is required by the Observer interface
  
  public void update(Observable o, Object arg)
  {
    Sphere balloon = (Sphere)o; 
    radiusIn.setText(" " + f3.format(balloon.getRadius()));
    volumeOut.setText(" " + f3.format(balloon.volume()));
    surfAreaOut.setText(" " + f3.format(balloon.surfaceArea()));
  }
}
