/**
 *  Case Study: "From Hello World to MVC"
 *  Authors: Maria Litvin and Gary Litvin
 *  February 2002
 *
 *  Project 7: The model (Sphere), two views (TextView and GraphicsView),
 *             and two controllers (TextController and GraphicsController)
 *             are in separate classes.
 * 
 *  This class implements the graphics controller (uses the mouse for input).
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class GraphicsController
    implements MouseListener, MouseMotionListener
{
  private GraphicsView view;
  private Sphere model;

  private boolean picked;
  private int anchorR, startR;

  public GraphicsController(Sphere balloon)
  {
    view = new GraphicsView();
    model = balloon;
    model.addObserver(view);
    view.addMouseListener(this);
    view.addMouseMotionListener(this);
    view.update(model, null);
  }

  public GraphicsView getView()
  {
    return view;
  }

  private double getDistance(int x, int y)
  {
    int x0 = (int)model.getX();
    int y0 = (int)model.getY();
    return Point.distance(x, y, x0, y0);
  }

  private boolean isOnBorder(int x, int y)
  {
    double r = model.getRadius();
    double d = getDistance(x, y);
    return d >= r * .9 && d <= r * 1.1;
  }


  public void mousePressed(MouseEvent e)
  {
    int x = e.getX() - view.getWidth() / 2;
    int y = e.getY() - view.getHeight() / 2;
    
    if (isOnBorder(x, y))
    {
      picked = true;
      anchorR = (int)getDistance(x, y);
      startR = (int)model.getRadius();
      view.update(model, null);
    }
  }

  public void mouseReleased(MouseEvent e)
  {
    picked = false;
    view.update(model, null);
  }

  public void mouseDragged(MouseEvent e)
  {
    if (!picked)
      return;

    int x = e.getX() - view.getWidth() / 2;
    int y = e.getY() - view.getHeight() / 2;
    double r = getDistance(x, y);
    model.setRadius(r - anchorR + startR);
  }

  // not used
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) {}
  public void mouseClicked(MouseEvent e) {}
  public void mouseMoved(MouseEvent e) {}
}
